==> sabrmetrics-0.3.1.tar.gz: sabrmetrics-0.3.1/README.md <==
# SABRmetrics

<div>
  <a href="https://github.com/JacobLee23/SABRmetrics/blob/master/LICENSE" target="_blank">
    <img src="https://img.shields.io/github/license/JacobLee23/SABRmetrics" alt="LICENSE">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/SABRmetrics" alt="PyPI - Python Version">
  <a href="https://github.com/JacobLee23/SABRmetrics/blob/master/Pipfile" target="_blank">
    <img src="https://img.shields.io/github/pipenv/locked/python-version/JacobLee23/SABRmetrics" alt="GitHub Pipenv locked Python version">
  </a>
  <a href="https://pypi.org/project/sabrmetrics/" target="_blank">
    <img src="https://img.shields.io/pypi/v/sabrmetrics" alt="PyPI">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/releases/latest" target="_blank">
    <img src="https://img.shields.io/github/v/release/JacobLee23/SABRmetrics" alt="GitHub release (latest SemVer)">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/tags" target="_blank">
    <img src="https://img.shields.io/github/v/tag/JacobLee23/SABRmetrics" alt="GitHub tag (latest SemVer)">
  </a>
</div>
<div>
  <img src="https://img.shields.io/github/languages/code-size/JacobLee23/SABRmetrics" alt="GitHub code size in bytes">
  <img src="https://img.shields.io/github/directory-file-count/JacobLee23/SABRmetrics" alt="GitHub repo file count">
  <img src="https://img.shields.io/github/repo-size/JacobLee23/SABRmetrics" alt="GitHub repo size">
  <img src="https://img.shields.io/github/commit-activity/m/JacobLee23/SABRmetrics" alt="Commit Activity (Month)">
  <img src="https://img.shields.io/github/last-commit/JacobLee23/SABRmetrics" alt="Last Commit">
</div>
<div>
  <a href="https://github.com/JacobLee23/SABRmetrics/issues" target="_blank">
    <img src="https://img.shields.io/github/issues-raw/JacobLee23/SABRmetrics" alt="GitHub issues">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/issues?q=is%3Aissue+is%3Aclosed" target="_blank">
    <img src="https://img.shields.io/github/issues-closed-raw/JacobLee23/SABRmetrics" alt="GitHub closed issues">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/pulls" target="_blank">
    <img src="https://img.shields.io/github/issues-pr-raw/JacobLee23/SABRmetrics" alt="GitHub pull requests">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/pulls?q=is%3Apr+is%3Aclosed" target="_blank">
    <img src="https://img.shields.io/github/issues-pr-closed-raw/JacobLee23/SABRmetrics" alt="GitHub closed pull requests">
  </a>
</div>

==> sabrmetrics-0.4.0.tar.gz: sabrmetrics-0.4.0/README.md <==
# SABRmetrics

<div>
  <a href="https://github.com/JacobLee23/SABRmetrics/blob/master/LICENSE" target="_blank">
    <img src="https://img.shields.io/github/license/JacobLee23/SABRmetrics" alt="LICENSE">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/SABRmetrics" alt="PyPI - Python Version">
  <a href="https://github.com/JacobLee23/SABRmetrics/blob/master/Pipfile" target="_blank">
    <img src="https://img.shields.io/github/pipenv/locked/python-version/JacobLee23/SABRmetrics" alt="GitHub Pipenv locked Python version">
  </a>
  <a href="https://pypi.org/project/sabrmetrics/" target="_blank">
    <img src="https://img.shields.io/pypi/v/sabrmetrics" alt="PyPI">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/releases/latest" target="_blank">
    <img src="https://img.shields.io/github/v/release/JacobLee23/SABRmetrics" alt="GitHub release (latest SemVer)">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/tags" target="_blank">
    <img src="https://img.shields.io/github/v/tag/JacobLee23/SABRmetrics" alt="GitHub tag (latest SemVer)">
  </a>
</div>
<div>
  <img src="https://img.shields.io/github/languages/code-size/JacobLee23/SABRmetrics" alt="GitHub code size in bytes">
  <a href="https://github.com/JacobLee23/SABRmetrics/find/master" target="_blank">
    <img src="https://img.shields.io/github/directory-file-count/JacobLee23/SABRmetrics" alt="GitHub repo file count">
  </a>
  <img src="https://img.shields.io/github/repo-size/JacobLee23/SABRmetrics" alt="GitHub repo size">
  <img src="https://img.shields.io/github/commit-activity/m/JacobLee23/SABRmetrics" alt="Commit Activity (Month)">
  <a href="https://github.com/JacobLee23/SABRmetrics/commits/master" target="_blank">
    <img src="https://img.shields.io/github/last-commit/JacobLee23/SABRmetrics" alt="Last Commit">
  </a>
</div>
<div>
  <a href="https://github.com/JacobLee23/SABRmetrics/issues" target="_blank">
    <img src="https://img.shields.io/github/issues-raw/JacobLee23/SABRmetrics" alt="GitHub issues">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/issues?q=is%3Aissue+is%3Aclosed" target="_blank">
    <img src="https://img.shields.io/github/issues-closed-raw/JacobLee23/SABRmetrics" alt="GitHub closed issues">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/pulls" target="_blank">
    <img src="https://img.shields.io/github/issues-pr-raw/JacobLee23/SABRmetrics" alt="GitHub pull requests">
  </a>
  <a href="https://github.com/JacobLee23/SABRmetrics/pulls?q=is%3Apr+is%3Aclosed" target="_blank">
    <img src="https://img.shields.io/github/issues-pr-closed-raw/JacobLee23/SABRmetrics" alt="GitHub closed pull requests">
  </a>
</div>

***

An open-source library of web-scraping software for popular SABRmetrics websites. 

> Sabermetrics (or originally as SABRmetrics) is the empirical analysis of baseball, especially baseball statistics that measure in-game activity. 

-- [Wikipedia](https://en.wikipedia.org/wiki/Sabermetrics)

> sabermetrics, the statistical analysis of baseball data. Sabermetrics aims to quantify baseball players’ performances based on objective statistical measurements, especially in opposition to many of the established statistics (such as, for example, runs batted in and pitching wins) that give less accurate approximations of individual efficacy.

-- [Britannica](https://www.britannica.com/sports/sabermetrics)
